==> 1.0.13.tar.gz: lib/src/images/helpers/image_helper.dart <==
part of modern_form_images;

class ModernFormImageHelper {
  static Future<List<Uint8List>> getImages() async {
    FilePickerResult? result = await FilePicker.platform.pickFiles(
      type: FileType.image,
      allowMultiple: true,
      withData: true,
    );

    List<Uint8List> bytes = <Uint8List>[];

    if (kIsWeb) {
      bytes = result?.files.map((e) => e.bytes ?? Uint8List(0)).toList() ??
          <Uint8List>[];
    } else {
      await Future.forEach((result?.files ?? <PlatformFile>[]),
          (PlatformFile e) async {
        File file = File(e.path);
        Uint8List b = await file.readAsBytes();
        bytes.add(b);
      });
    }

    return bytes;
  }

  static Future<XFile?> pickImage(
    ImageSource? imageSource, {
    double? maxWidth,
    double? maxHeight,
    int? imageQuality,
  }) async {
    try {
      if (ModernFormUtils.isIos) {
        FilePickerResult? result = await FilePicker.platform.pickFiles(
          type: FileType.image,
          allowMultiple: false,
          withData: true,
          allowCompression: true,
        );

        if (result != null && result.count > 0) {
          return XFile(result.paths[0]!);
        } else {
          return null;
        }
      } else {
        ImagePicker picker = ImagePicker();
        XFile? pickedFile = await picker.pickImage(
          source: imageSource ?? ImageSource.gallery,
          maxWidth: maxWidth,
          maxHeight: maxHeight,
          imageQuality: imageQuality ?? 70,
        );

        return pickedFile;
      }
    } catch (e) {
      return null;
    }
  }

  static Future<ImageSource?> showBottonSheetImageSource() async {
    if (kIsWeb) {
      return ImageSource.gallery;
    }
    BuildContext context = ModernFormGlobalContext.context!;
    return await showModalBottomSheet(
      context: context,
      builder: (BuildContext context) {
        return SafeArea(
          child: SingleChildScrollView(
            child: Container(
              child: Wrap(
                children: <Widget>[
                  ListTile(
                      onTap: () {
                        Navigator.pop(context, ImageSource.camera);
                      },
                      title: Text("Câmera"),
                      leading: Icon(Icons.camera_alt)),
                  ListTile(
                      onTap: () {
                        Navigator.pop(context, ImageSource.gallery);
                      },
                      title: Text("Galeria"),
                      leading: Icon(Icons.image)),
                ],
              ),
            ),
          ),
        );
      },
    );
  }

  static Future<void> shareImage(
    Uint8List image,
    String? text, {
    String? title,
    String? name,
  }) async {
    await Share.file(
      title ?? '',
      name ?? 'image.png',
      image,
      'image/png',
      text: text ?? "",
    );
  }

  static Future<void> shareImageFromUrl(String? imageUrl, String? text) async {
    if (kIsWeb) {
      String? value =
          text != null && text.isNotEmpty ? '$text - $imageUrl' : imageUrl;
      await Clipboard.setData(ClipboardData(text: value));
      showFlushBar(value: true, textTrue: "Texto copiado");
    } else {
      Uint8List? bytes =
          await (ModernFormDownloadHelper.downloadWithProgress(imageUrl));
      if (bytes != null) {
        await shareImage(bytes, text);
      }
    }
  }

  static Future<void> shareMultipleImages(
    List<Uint8List?> images,
    String? text, {
    String? title,
    String? name,
  }) async {
    Map<String, List<int>> files = {};

    for (var i = 0; i < images.length; i++) {
      Uint8List data = images[i]!;
      files['$i.png'] = data;
    }

    await Share.files(title ?? '', files, name ?? 'image/png',
        text: text ?? "");
  }

  static Future<void> shareMultipleImagesFromUrl(
    List<String> urls,
    String text,
  ) async {
    List<Uint8List?> images = <Uint8List?>[];

    await Future.forEach(urls, (String url) async {
      Uint8List? bytes =
          await ModernFormDownloadHelper.downloadWithProgress(url);
      images.add(bytes);
    });

    await shareMultipleImages(images, text);
  }
}

==> 1.1.0.tar.gz: lib/src/images/helpers/image_helper.dart <==
part of modern_form_images;

class ModernFormImageHelper {
  static Future<List<Uint8List>> getImages() async {
    FilePickerResult? result = await FilePicker.platform.pickFiles(
      type: FileType.image,
      allowMultiple: true,
      withData: true,
    );

    List<Uint8List> bytes = <Uint8List>[];

    if (kIsWeb) {
      bytes = result?.files.map((e) => e.bytes ?? Uint8List(0)).toList() ??
          <Uint8List>[];
    } else {
      await Future.forEach((result?.files ?? <PlatformFile>[]),
          (PlatformFile e) async {
        if (e.path != null) {
          File file = File(e.path!);
          Uint8List b = await file.readAsBytes();
          bytes.add(b);
        }
      });
    }

    return bytes;
  }

  static Future<XFile?> pickImage(
    ImageSource? imageSource, {
    double? maxWidth,
    double? maxHeight,
    int? imageQuality,
  }) async {
    try {
      if (ModernFormUtils.isIos) {
        FilePickerResult? result = await FilePicker.platform.pickFiles(
          type: FileType.image,
          allowMultiple: false,
          withData: true,
          allowCompression: true,
        );

        if (result != null && result.count > 0) {
          return XFile(result.paths[0]!);
        } else {
          return null;
        }
      } else {
        ImagePicker picker = ImagePicker();
        XFile? pickedFile = await picker.pickImage(
          source: imageSource ?? ImageSource.gallery,
          maxWidth: maxWidth,
          maxHeight: maxHeight,
          imageQuality: imageQuality ?? 70,
        );

        return pickedFile;
      }
    } catch (e) {
      return null;
    }
  }

  static Future<ImageSource?> showBottonSheetImageSource() async {
    if (kIsWeb) {
      return ImageSource.gallery;
    }
    BuildContext context = ModernFormGlobalContext.context!;
    return await showModalBottomSheet(
      context: context,
      builder: (BuildContext context) {
        return SafeArea(
          child: SingleChildScrollView(
            child: Container(
              child: Wrap(
                children: <Widget>[
                  ListTile(
                      onTap: () {
                        Navigator.pop(context, ImageSource.camera);
                      },
                      title: Text("Câmera"),
                      leading: Icon(Icons.camera_alt)),
                  ListTile(
                      onTap: () {
                        Navigator.pop(context, ImageSource.gallery);
                      },
                      title: Text("Galeria"),
                      leading: Icon(Icons.image)),
                ],
              ),
            ),
          ),
        );
      },
    );
  }

  static Future<void> shareImage(
    Uint8List image,
    String? text, {
    String? title,
    String? name,
  }) async {
    await Share.file(
      title ?? '',
      name ?? 'image.png',
      image,
      'image/png',
      text: text ?? "",
    );
  }

  static Future<void> shareImageFromUrl(String? imageUrl, String? text) async {
    if (kIsWeb) {
      String? value =
          text != null && text.isNotEmpty ? '$text - $imageUrl' : imageUrl;
      await Clipboard.setData(ClipboardData(text: value));
      showFlushBar(value: true, textTrue: "Texto copiado");
    } else {
      Uint8List? bytes =
          await (ModernFormDownloadHelper.downloadWithProgress(imageUrl));
      if (bytes != null) {
        await shareImage(bytes, text);
      }
    }
  }

  static Future<void> shareMultipleImages(
    List<Uint8List?> images,
    String? text, {
    String? title,
    String? name,
  }) async {
    Map<String, List<int>> files = {};

    for (var i = 0; i < images.length; i++) {
      Uint8List data = images[i]!;
      files['$i.png'] = data;
    }

    await Share.files(title ?? '', files, name ?? 'image/png',
        text: text ?? "");
  }

  static Future<void> shareMultipleImagesFromUrl(
    List<String> urls,
    String text,
  ) async {
    List<Uint8List?> images = <Uint8List?>[];

    await Future.forEach(urls, (String url) async {
      Uint8List? bytes =
          await ModernFormDownloadHelper.downloadWithProgress(url);
      images.add(bytes);
    });

    await shareMultipleImages(images, text);
  }
}
